{% extends 'spectator_core/base.html' %}
{% load spectator_core %}

{% block head_title %}Spectator{% endblock %}
{% block content_title %}Spectator{% endblock %}

{% block breadcrumbs %}
  <li class="breadcrumb-item active">Home</li>
{% endblock %}

{% block content %}

  {% if in_progress_publication_list|length > 0 %}
    <h2>Currently reading</h2>

    {% include 'spectator_reading/includes/publications.html' with publication_list=in_progress_publication_list show_readings='current' show_thumbnails=True only %}
  {% endif %}

  {% if recent_event_list|length > 0 %}
    <h2>Recent events</h2>

    {% include 'spectator_events/includes/events.html' with event_list=recent_event_list only %}

  {% endif %}

{% endblock content %}


{% block sidebar_content %}
  {{ block.super }}

  {% most_read_creators_card num=10 %}

  {% most_visited_venues_card num=10 %}

{% endblock sidebar_content %}
