{% comment %}
Displays a list of Events.

Expects:
* event_list - List or Queryset of children of Event.
* style: 'bullets' (default) or 'unstyled'.

{% endcomment %}

{% load spectator_events %}

{% if event_list|length > 0 %}
  <ul{% if style|default:'bullets' == 'unstyled' %} class="list-unstyled mb-0"{% endif %}>
    {% for event in event_list %}
      <li class="mb-2">
        <a href="{{ event.get_absolute_url }}"><strong>{{ event.title_html }}</strong><br>
        {% if event.venue %}{{ event.venue_name }}, {% endif %}{% display_date event.date %}</a>
      </li>
    {% endfor %}
  </ul>
{% endif %}
