# Generated by Django 5.1.4 on 2025-04-22 08:56

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spectator_events', '0045_auto_20201221_1358'),
    ]

    operations = [
        migrations.AlterField(
            model_name='work',
            name='imdb_id',
            field=models.CharField(blank=True, help_text='Starts with \'tt\', e.g. \'tt0100842\'.\n            From <a href="https://www.imdb.com">IMDb</a>.', max_length=12, validators=[django.core.validators.RegexValidator(code='invalid_imdb_id', message='IMDb ID should be like "tt1234567"', regex='^tt[0-9]{7,10}$')], verbose_name='IMDb ID'),
        ),
    ]
