{% extends 'spectator_core/base.html' %}

{% load spectator_core spectator_events %}

{% block events_nav_active %}active{% endblock %}

{% block breadcrumbs %}
  {{ block.super }}
  <li class="breadcrumb-item"><a href="{% url 'spectator:events:home' %}">Events</a></li>
{% endblock %}

{% block sidebar_nav %}
  {% include 'spectator_events/includes/card_nav.html' %}
  {% include 'spectator_core/includes/card_nav.html' %}
{% endblock sidebar_nav %}

{% block sidebar_content %}
  {% current_url_name as url_name %}

  {% if url_name != 'spectator:events:home' and url_name != 'spectator:events:event_year_archive'%}
    {% recent_events_card 5 %}
  {% endif %}

  {% comment %}
    Just links to year pages: #}
    {% events_years_card current_year=year %}
  {% endcomment %}

  {% if event_kind %}
    {% annual_event_counts_card current_year=year kind=event_kind %}
  {% else %}
    {% annual_event_counts_card current_year=year %}
  {% endif %}
{% endblock sidebar_content %}
