# Generated by Django 2.0 on 2018-01-25 13:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_events", "0010_auto_20180118_0906"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="classicalwork",
            options={"ordering": ("title_sort",), "verbose_name": "classical work"},
        ),
        migrations.AlterModelOptions(
            name="classicalworkrole",
            options={
                "ordering": ("role_order", "role_name"),
                "verbose_name": "classical work role",
            },
        ),
        migrations.AlterModelOptions(
            name="dancepiece",
            options={"ordering": ("title_sort",), "verbose_name": "dance piece"},
        ),
        migrations.AlterModelOptions(
            name="dancepiecerole",
            options={
                "ordering": ("role_order", "role_name"),
                "verbose_name": "dance piece role",
            },
        ),
        migrations.AlterModelOptions(
            name="eventrole",
            options={
                "ordering": ("role_order", "role_name"),
                "verbose_name": "event role",
            },
        ),
        migrations.AlterModelOptions(
            name="movierole",
            options={
                "ordering": ("role_order", "role_name"),
                "verbose_name": "movie role",
            },
        ),
        migrations.AlterModelOptions(
            name="playrole",
            options={
                "ordering": ("role_order", "role_name"),
                "verbose_name": "play role",
            },
        ),
    ]
