# Generated by Django 3.0.5 on 2020-04-07 10:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_reading", "0006_publication_cover"),
    ]

    operations = [
        migrations.RenameField(
            model_name="publication",
            old_name="cover",
            new_name="thumbnail",
        ),
    ]
