# Generated by Django 2.0 on 2018-04-17 17:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_events", "0039_populate_exhibitions"),
    ]

    operations = [
        migrations.AlterField(
            model_name="work",
            name="kind",
            field=models.CharField(
                choices=[
                    ("classicalwork", "Classical work"),
                    ("dancepiece", "Dance piece"),
                    ("exhibition", "Exhibition"),
                    ("movie", "Movie"),
                    ("play", "Play"),
                ],
                max_length=20,
            ),
        ),
    ]
