# Generated by Django 2.0 on 2018-04-17 12:18

from django.db import migrations


def forwards(apps, schema_editor):
    """
    Migrate all 'exhibition' Events to the new 'museum' Event kind.
    """
    Event = apps.get_model("spectator_events", "Event")

    for ev in Event.objects.filter(kind="exhibition"):
        ev.kind = "museum"
        ev.save()


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_events", "0036_auto_20180417_1218"),
    ]

    operations = [
        migrations.RunPython(forwards),
    ]
