{% comment %}
Expects:

* publication_list: The list or QuerySet of Publications to display.
* show_readings: 'none' (default), 'all' or 'current' (the in-progress reading, if any).
* show_thumbnails: Boolean, default is False.
* style: 'bullets' (default) or 'unstyled'.

{% endcomment %}

<ul{% if style|default:'bullets' == 'unstyled' %} class="list-unstyled mb-0"{% endif %}>
  {% for publication in publication_list %}
    <li class="mb-2">
      {% include 'spectator_reading/includes/publication.html' with publication=publication show_readings=show_readings|default:'none' show_thumbnail=show_thumbnails|default_if_none:False only %}
    </li>
  {% endfor %}
</ul>
