# Generated by Django 2.0 on 2018-01-26 09:16

from django.db import migrations


class Migration(migrations.Migration):
    """
    Now we've copied their data to the new movies and plays m2m fields,
    we can remove the old movie and play fk fields.
    """

    dependencies = [
        ("spectator_events", "0017_copy_movies_and_plays_data"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="event",
            name="movie",
        ),
        migrations.RemoveField(
            model_name="event",
            name="play",
        ),
    ]
