# Generated by Django 3.0.5 on 2020-04-07 10:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("spectator_events", "0042_auto_20200407_1039"),
    ]

    operations = [
        migrations.RenameField(
            model_name="event",
            old_name="ticket",
            new_name="thumbnail",
        ),
    ]
